@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2005 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2006 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,12 +26,12 @@ namespace Browser
 class SearchFolder :public Folder {
 
 public:
-    SearchFolder( const ImageSearchInfo& info, Browser* browser );
+    SearchFolder( const DB::ImageSearchInfo& info, BrowserWidget* browser );
     virtual FolderAction* action( bool ctrlDown = false );
     virtual QPixmap pixmap();
     virtual QString text() const;
-    virtual QString countLabel() const;
-
+    virtual QString imagesLabel() const;
+    virtual QString videosLabel() const;
 };
 
 }
