@@ -1,11 +1,27 @@
+/* Copyright (C) 2003-2006 Jesper K. Pedersen <blackie@kde.org>
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
+   Boston, MA 02110-1301, USA.
+*/
 #ifndef EXIFDATABASE_H
 #define EXIFDATABASE_H
 
 #include <qstring.h>
 #include <qvaluelist.h>
 #include <qpair.h>
-#include <qstringlist.h>
-#include <set.h>
+#include "Utilities/Set.h"
 
 class QSqlDatabase;
 class QSqlQuery;
@@ -32,6 +48,8 @@ public:
     static Database* instance();
     static bool isAvailable();
 
+    bool isOpen() const;
+    bool isUsable() const;
     void add( const QString& fileName );
     void remove( const QString& fileName );
     Set<QString> filesMatchingQuery( const QString& query );
@@ -46,6 +64,7 @@ protected:
     void offerInitialize();
 
 private:
+    bool _isOpen;
     Database();
     void init();
     static Database* _instance;
