@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2005 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2006 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,8 +19,6 @@
 #ifndef REREADDIALOG_H
 #define REREADDIALOG_H
 #include <kdialogbase.h>
-#include "imageinfolist.h"
-#include <config.h>
 class QLabel;
 class QCheckBox;
 class QRadioButton;
