@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2005 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2006 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -29,29 +29,24 @@
 #include <qlayout.h>
 #include <klineedit.h>
 #include <kpushbutton.h>
-#include "options.h"
+#include "Settings/SettingsData.h"
 #include "ImportMatcher.h"
 #include <qcheckbox.h>
-#include <qcombobox.h>
-#include "util.h"
-#include "imagedb.h"
+#include "Utilities/Util.h"
+#include "DB/ImageDB.h"
 #include <qimage.h>
-#include <qwmatrix.h>
-#include "Browser/Browser.h"
-#include <qdir.h>
+#include "Browser/BrowserWidget.h"
 #include <kstandarddirs.h>
 #include <ktempfile.h>
 #include <kurl.h>
-#include <kio/job.h>
 #include <qprogressdialog.h>
 #include <kio/netaccess.h>
-#include "mainview.h"
+#include "MainWindow/Window.h"
 #include <kapplication.h>
-#include "categorycollection.h"
-#include "imageinfo.h"
+#include "DB/CategoryCollection.h"
+#include "DB/ImageInfo.h"
 #include "MiniViewer.h"
-#include "XMLDB/XMLDB.h"
-#include <kdebug.h>
+#include "XMLDB/Database.h"
 
 class KPushButton;
 using namespace ImportExport;
@@ -176,8 +171,8 @@ bool Import::readFile( const QByteArray& data, const QString& fileName )
     // Read source
     QString source = top.attribute( QString::fromLatin1( "location" ) ).lower();
     if ( source != QString::fromLatin1( "inline" ) && source != QString::fromLatin1( "external" ) ) {
-        KMessageBox::error( this, i18n("<qt>XML file did not specify the source of the images, "
-                                       "this is a strong indication that the file is corrupted</qt>" ) );
+        KMessageBox::error( this, i18n("<p>XML file did not specify the source of the images, "
+                                       "this is a strong indication that the file is corrupted</p>" ) );
         return false;
     }
 
@@ -193,7 +188,7 @@ bool Import::readFile( const QByteArray& data, const QString& fileName )
         }
         QDomElement elm = node.toElement();
 
-        ImageInfoPtr info = XMLDB::XMLDB::createImageInfo( elm.attribute( QString::fromLatin1( "file" ) ), elm );
+        DB::ImageInfoPtr info = XMLDB::Database::createImageInfo( elm.attribute( QString::fromLatin1( "file" ) ), elm );
         _images.append( info );
     }
 
@@ -205,7 +200,7 @@ void Import::setupPages()
     createIntroduction();
     createImagesPage();
     createDestination();
-    createOptionPages();
+    createCategoryPages();
     connect( this, SIGNAL( selected( const QString& ) ), this, SLOT( updateNextButtonState() ) );
     connect( finishButton(), SIGNAL( clicked() ), this, SLOT( slotFinish() ) );
     connect( this, SIGNAL( helpClicked() ), this, SLOT( slotHelp() ) );
@@ -213,23 +208,22 @@ void Import::setupPages()
 
 void Import::createIntroduction()
 {
-    QString txt = i18n( "<qt><h1><font size=\"+2\">Welcome to KPhotoAlbum Import</font></h1>"
-                        "This wizard will take you through the steps of an import operation, The steps are: "
-                        "<ul><li>First you must select which images you want to import from the export file. "
+    QString txt = i18n( "<h1><font size=\"+2\">Welcome to KPhotoAlbum Import</font></h1>"
+                        "This wizard will take you through the steps of an import operation. The steps are: "
+                        "<ol><li>First you must select which images you want to import from the export file. "
                         "You do so by selecting the checkbox next to the image.</li>"
                         "<li>Next you must tell KPhotoAlbum in which directory to put the images. This directory must "
                         "of course be below the directory root KPhotoAlbum uses for images. "
                         "KPhotoAlbum will take care to avoid name clashes</li>"
-                        "<li>The next step is to specify which categories you want to import (Persons, Locations, ... ) "
+                        "<li>The next step is to specify which categories you want to import (People, Places, ... ) "
                         "and also tell KPhotoAlbum how to match the categories from the file to your categories. "
-                        "Imagine you load from a file, where a category is called <tt>Blomst</tt> (which is the "
+                        "Imagine you load from a file, where a category is called <b>Blomst</b> (which is the "
                         "Danish word for flower), then you would likely want to match this with your category, which might be "
-                        "called <tt>Blume</tt> (which is the German word for flower) - of course given you are German.</li>"
-                        "<li>The final steps, is matching the individual tokens from the categories. I may call myself <tt>Jesper</tt> "
-                        "in my image database, while you want to call me by my full name, namely <tt>Jesper K. Pedersen</tt>. "
+                        "called <b>Blume</b> (which is the German word for flower) - of course given you are German.</li>"
+                        "<li>The final steps, is matching the individual tokens from the categories. I may call myself <b>Jesper</b> "
+                        "in my image database, while you want to call me by my full name, namely <b>Jesper K. Pedersen</b>. "
                         "In this step non matches will be highlighted in red, so you can see which tokens was not found in your "
-                        "database, or which tokens was only a partial match.</li>"
-                        "</p></qt>" );
+                        "database, or which tokens was only a partial match.</li></ol>");
 
     QLabel* intro = new QLabel( txt, this );
     addPage( intro, i18n("Introduction") );
@@ -258,8 +252,8 @@ void Import::createImagesPage()
     lay3->setColStretch( 2, 1 );
 
     int row = 0;
-    for( ImageInfoListConstIterator it = _images.constBegin(); it != _images.constEnd(); ++it, ++row ) {
-        ImageInfoPtr info = *it;
+    for( DB::ImageInfoListConstIterator it = _images.constBegin(); it != _images.constEnd(); ++it, ++row ) {
+        DB::ImageInfoPtr info = *it;
         ImageRow* ir = new ImageRow( info, this, container );
         lay3->addWidget( ir->_checkbox, row, 0 );
 
@@ -275,7 +269,7 @@ void Import::createImagesPage()
             lay3->addWidget( label, row, 1 );
         }
 
-        QLabel* label = new QLabel( QString::fromLatin1("<qt>%1</qt>").arg(info->description()), container, "description" );
+        QLabel* label = new QLabel( QString::fromLatin1("<p>%1</p>").arg(info->description()), container, "description" );
         lay3->addWidget( label, row, 2 );
         _imagesSelect.append( ir );
     }
@@ -283,7 +277,7 @@ void Import::createImagesPage()
     addPage( top, i18n("Select Which Images to Import") );
 }
 
-ImageRow::ImageRow( ImageInfoPtr info, Import* import, QWidget* parent )
+ImageRow::ImageRow( DB::ImageInfoPtr info, Import* import, QWidget* parent )
     : QObject( parent ), _info( info ), _import( import )
 {
     _checkbox = new QCheckBox( QString::null, parent, "_checkbox" );
@@ -303,7 +297,7 @@ void ImageRow::showImage()
             src.setFileName( _info->fileName( true ) );
             QString tmpFile;
 
-            if( KIO::NetAccess::download( src, tmpFile, MainView::theMainView() ) ) {
+            if( KIO::NetAccess::download( src, tmpFile, MainWindow::Window::theMainWindow() ) ) {
                 QImage img( tmpFile );
                 MiniViewer::show( img, _info );
                 KIO::NetAccess::removeTempFile( tmpFile );
@@ -336,7 +330,7 @@ void Import::createDestination()
     lay->addWidget( but );
 
 
-    _destinationEdit->setText( Options::instance()->imageDirectory());
+    _destinationEdit->setText( Settings::SettingsData::instance()->imageDirectory());
     connect( but, SIGNAL( clicked() ), this, SLOT( slotEditDestination() ) );
     connect( _destinationEdit, SIGNAL( textChanged( const QString& ) ), this, SLOT( updateNextButtonState() ) );
     addPage( top, i18n("Destination of Images" ) );
@@ -346,8 +340,8 @@ void  Import::slotEditDestination()
 {
     QString file = KFileDialog::getExistingDirectory( _destinationEdit->text(), this );
     if ( !file.isNull() ) {
-        if ( ! QFileInfo(file).absFilePath().startsWith( QFileInfo(Options::instance()->imageDirectory()).absFilePath()) ) {
-            KMessageBox::error( this, i18n("The directory must be a subdirectory of %1").arg( Options::instance()->imageDirectory() ) );
+        if ( ! QFileInfo(file).absFilePath().startsWith( QFileInfo(Settings::SettingsData::instance()->imageDirectory()).absFilePath()) ) {
+            KMessageBox::error( this, i18n("The directory must be a subdirectory of %1").arg( Settings::SettingsData::instance()->imageDirectory() ) );
         }
         else {
             _destinationEdit->setText( file );
@@ -363,29 +357,29 @@ void Import::updateNextButtonState()
         QString dest = _destinationEdit->text();
         if ( QFileInfo( dest ).isFile() )
             enabled = false;
-        else if ( ! QFileInfo(dest).absFilePath().startsWith( QFileInfo(Options::instance()->imageDirectory()).absFilePath()) )
+        else if ( ! QFileInfo(dest).absFilePath().startsWith( QFileInfo(Settings::SettingsData::instance()->imageDirectory()).absFilePath()) )
             enabled = false;
     }
 
     nextButton()->setEnabled( enabled );
 }
 
-void Import::createOptionPages()
+void Import::createCategoryPages()
 {
-    QStringList options;
-    ImageInfoList images = selectedImages();
-    for( ImageInfoListConstIterator it = images.constBegin(); it != images.constEnd(); ++it ) {
-        ImageInfoPtr info = *it;
-        QStringList opts = info->availableCategories();
-        for( QStringList::Iterator optsIt = opts.begin(); optsIt != opts.end(); ++optsIt ) {
-            if ( !options.contains( *optsIt ) &&
-                 (*optsIt) != QString::fromLatin1( "Folder" ) &&
-                 (*optsIt) != QString::fromLatin1( "Tokens" ) )
-                options.append( *optsIt );
+    QStringList categories;
+    DB::ImageInfoList images = selectedImages();
+    for( DB::ImageInfoListConstIterator it = images.constBegin(); it != images.constEnd(); ++it ) {
+        DB::ImageInfoPtr info = *it;
+        QStringList categoriesForImage = info->availableCategories();
+        for( QStringList::Iterator categoryIt = categoriesForImage.begin(); categoryIt != categoriesForImage.end(); ++categoryIt ) {
+            if ( !categories.contains( *categoryIt ) &&
+                 (*categoryIt) != QString::fromLatin1( "Folder" ) &&
+                 (*categoryIt) != QString::fromLatin1( "Tokens" ) )
+                categories.append( *categoryIt );
         }
     }
 
-    _categoryMatcher = new ImportMatcher( QString::null, QString::null, options, ImageDB::instance()->categoryCollection()->categoryNames(),
+    _categoryMatcher = new ImportMatcher( QString::null, QString::null, categories, DB::ImageDB::instance()->categoryCollection()->categoryNames(),
                                           false, this, "import matcher" );
     addPage( _categoryMatcher, i18n("Match Categories") );
 
@@ -393,22 +387,22 @@ void Import::createOptionPages()
     addPage( _dummy, QString::null );
 }
 
-ImportMatcher* Import::createOptionPage( const QString& myOptionGroup, const QString& otherOptionGroup )
+ImportMatcher* Import::createCategoryPage( const QString& myCategory, const QString& otherCategory )
 {
-    QStringList otherOptions;
-    ImageInfoList images = selectedImages();
-    for( ImageInfoListConstIterator it = images.constBegin(); it != images.constEnd(); ++it ) {
-        ImageInfoPtr info = *it;
-        QStringList opts = info->itemsOfCategory( otherOptionGroup );
-        for( QStringList::Iterator optsIt = opts.begin(); optsIt != opts.end(); ++optsIt ) {
-            if ( !otherOptions.contains( *optsIt ) )
-                otherOptions.append( *optsIt );
-        }
+    QStringList otherItems;
+    DB::ImageInfoList images = selectedImages();
+    for( DB::ImageInfoListConstIterator it = images.constBegin(); it != images.constEnd(); ++it ) {
+        DB::ImageInfoPtr info = *it;
+        StringSet items = info->itemsOfCategory( otherCategory );
+        for( StringSet::ConstIterator itemIt = items.begin(); itemIt != items.end(); ++itemIt )
+            otherItems.append( *itemIt );
     }
 
-    QStringList myOptions = ImageDB::instance()->categoryCollection()->categoryForName( myOptionGroup )->itemsInclGroups();
-    ImportMatcher* matcher = new ImportMatcher( otherOptionGroup, myOptionGroup, otherOptions, myOptions, true, this, "import matcher" );
-    addPage( matcher, myOptionGroup );
+    QStringList myItems = DB::ImageDB::instance()->categoryCollection()->categoryForName( myCategory )->itemsInclCategories();
+    myItems.sort();
+
+    ImportMatcher* matcher = new ImportMatcher( otherCategory, myCategory, otherItems, myItems, true, this, "import matcher" );
+    addPage( matcher, myCategory );
     return matcher;
 }
 
@@ -435,13 +429,13 @@ void Import::next()
         delete _dummy;
 
         ImportMatcher* matcher = 0;
-        for( QValueList<OptionMatch*>::Iterator it = _categoryMatcher->_matchers.begin();
+        for( QValueList<CategoryMatch*>::Iterator it = _categoryMatcher->_matchers.begin();
              it != _categoryMatcher->_matchers.end();
              ++it )
         {
-            OptionMatch* match = *it;
+            CategoryMatch* match = *it;
             if ( match->_checkbox->isChecked() ) {
-                matcher = createOptionPage( match->_combobox->currentText(), match->_text );
+                matcher = createCategoryPage( match->_combobox->currentText(), match->_text );
                 _matchers.append( matcher );
             }
         }
@@ -456,15 +450,15 @@ void Import::next()
 
 bool Import::copyFilesFromZipFile()
 {
-    ImageInfoList images = selectedImages();
-    for( ImageInfoListConstIterator it = images.constBegin(); it != images.constEnd(); ++it ) {
+    DB::ImageInfoList images = selectedImages();
+    for( DB::ImageInfoListConstIterator it = images.constBegin(); it != images.constEnd(); ++it ) {
         QString fileName = (*it)->fileName( true );
         QByteArray data = loadImage( fileName );
         if ( data.isNull() )
             return false;
-        QString newName = Options::instance()->imageDirectory() + _nameMap[fileName];
+        QString newName = Settings::SettingsData::instance()->imageDirectory() + _nameMap[fileName];
 
-        QString relativeName = newName.mid( Options::instance()->imageDirectory().length() );
+        QString relativeName = newName.mid( Settings::SettingsData::instance()->imageDirectory().length() );
         if ( relativeName.startsWith( QString::fromLatin1( "/" ) ) )
             relativeName= relativeName.mid(1);
 
@@ -492,7 +486,7 @@ void Import::copyFromExternal()
 
 void Import::copyNextFromExternal()
 {
-    ImageInfoPtr info = _pendingCopies[0];
+    DB::ImageInfoPtr info = _pendingCopies[0];
     _pendingCopies.pop_front();
     QString fileName = info->fileName( true );
     KURL src1 = _kimFile;
@@ -503,9 +497,9 @@ void Import::copyNextFromExternal()
             src = src2;
 
         src.setFileName( fileName );
-        if ( KIO::NetAccess::exists( src, true, MainView::theMainView() ) ) {
+        if ( KIO::NetAccess::exists( src, true, MainWindow::Window::theMainWindow() ) ) {
             KURL dest;
-            dest.setPath( Options::instance()->imageDirectory() + _nameMap[fileName] );
+            dest.setPath( Settings::SettingsData::instance()->imageDirectory() + _nameMap[fileName] );
             _job = KIO::file_copy( src, dest, -1, false, false, false );
             connect( _job, SIGNAL( result( KIO::Job* ) ), this, SLOT( aCopyJobCompleted( KIO::Job* ) ) );
             break;
@@ -544,7 +538,7 @@ void Import::stopCopyingImages()
 void Import::slotFinish()
 {
     _finishedPressed = true;
-    _nameMap = Util::createUniqNameMap( Util::infoListToStringList(selectedImages()), true, _destinationEdit->text() );
+    _nameMap = Utilities::createUniqNameMap( Utilities::infoListToStringList(selectedImages()), true, _destinationEdit->text() );
     bool ok;
     if ( _externalSource ) {
         hide();
@@ -561,43 +555,43 @@ void Import::slotFinish()
 void Import::updateDB()
 {
     // Run though all images
-    ImageInfoList images = selectedImages();
-    for( ImageInfoListConstIterator it = images.constBegin(); it != images.constEnd(); ++it ) {
-        ImageInfoPtr info = *it;
+    DB::ImageInfoList images = selectedImages();
+    for( DB::ImageInfoListConstIterator it = images.constBegin(); it != images.constEnd(); ++it ) {
+        DB::ImageInfoPtr info = *it;
 
-        ImageInfoPtr newInfo = new ImageInfo( _nameMap[info->fileName(true)] );
+        DB::ImageInfoPtr newInfo = new DB::ImageInfo( _nameMap[info->fileName(true)] );
         newInfo->setLabel( info->label() );
         newInfo->setDescription( info->description() );
         newInfo->setDate( info->date() );
         newInfo->rotate( info->angle() );
         newInfo->setDrawList( info->drawList() );
         newInfo->setMD5Sum( info->MD5Sum() );
-        ImageInfoList list;
+        DB::ImageInfoList list;
         list.append(newInfo);
-        ImageDB::instance()->addImages( list );
+        DB::ImageDB::instance()->addImages( list );
 
         // Run though the categories
         for( QValueList<ImportMatcher*>::Iterator grpIt = _matchers.begin(); grpIt != _matchers.end(); ++grpIt ) {
-            QString otherGrp = (*grpIt)->_otherOptionGroup;
-            QString myGrp = (*grpIt)->_myOptionGroup;
+            QString otherGrp = (*grpIt)->_otherCategory;
+            QString myGrp = (*grpIt)->_myCategory;
 
             // Run through each option
-            QValueList<OptionMatch*>& matcher = (*grpIt)->_matchers;
-            for( QValueList<OptionMatch*>::Iterator optionIt = matcher.begin(); optionIt != matcher.end(); ++optionIt ) {
+            QValueList<CategoryMatch*>& matcher = (*grpIt)->_matchers;
+            for( QValueList<CategoryMatch*>::Iterator optionIt = matcher.begin(); optionIt != matcher.end(); ++optionIt ) {
                 if ( !(*optionIt)->_checkbox->isChecked() )
                     continue;
                 QString otherOption = (*optionIt)->_text;
                 QString myOption = (*optionIt)->_combobox->currentText();
 
-                if ( info->hasOption( otherGrp, otherOption ) ) {
-                    newInfo->addOption( myGrp, myOption );
-                    ImageDB::instance()->categoryCollection()->categoryForName( myGrp )->addItem( myOption );
+                if ( info->hasCategoryInfo( otherGrp, otherOption ) ) {
+                    newInfo->addCategoryInfo( myGrp, myOption );
+                    DB::ImageDB::instance()->categoryCollection()->categoryForName( myGrp )->addItem( myOption );
                 }
 
             }
         }
     }
-    Browser::Browser::instance()->home();
+    Browser::BrowserWidget::instance()->home();
 }
 
 QPixmap Import::loadThumbnail( QString fileName )
@@ -612,7 +606,8 @@ QPixmap Import::loadThumbnail( QString fileName )
 
     const KArchiveDirectory* thumbnailDir = static_cast<const KArchiveDirectory*>( thumbnails );
 
-    fileName = QFileInfo( fileName ).fileName();
+    const QString ext = Utilities::isVideo( fileName ) ? QString::fromLatin1( "jpg" ) : QFileInfo( fileName ).extension();
+    fileName = QString::fromLatin1("%1.%2").arg( Utilities::stripSlash( QFileInfo( fileName ).baseName() ) ).arg(ext);
     const KArchiveEntry* fileEntry = thumbnailDir->entry( fileName );
     if ( fileEntry == 0 || !fileEntry->isFile() ) {
         KMessageBox::error( this, i18n("No thumbnail existed in export file for %1").arg( fileName ) );
@@ -667,9 +662,9 @@ QByteArray Import::loadImage( const QString& fileName )
     return data;
 }
 
-ImageInfoList Import::selectedImages()
+DB::ImageInfoList Import::selectedImages()
 {
-    ImageInfoList res;
+    DB::ImageInfoList res;
     for( QValueList<ImageRow*>::Iterator it = _imagesSelect.begin(); it != _imagesSelect.end(); ++it ) {
         if ( (*it)->_checkbox->isChecked() )
             res.append( (*it)->_info );
