@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2005 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2006 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,7 +19,7 @@
 #ifndef INFOBOX_H
 #define INFOBOX_H
 #include <qtextbrowser.h>
-#include "Viewer.h"
+#include "ViewerWidget.h"
 class QToolButton;
 
 namespace Viewer
@@ -28,7 +28,7 @@ class InfoBox :public QTextBrowser {
     Q_OBJECT
 
 public:
-    InfoBox( Viewer* parent, const char* name = 0 );
+    InfoBox( ViewerWidget* parent, const char* name = 0 );
     void setInfo( const QString& text, const QMap<int, QPair<QString,QString> >& linkMap );
     virtual void setSource( const QString& which );
     void setSize();
@@ -42,7 +42,7 @@ protected:
 
 private:
     QMap<int, QPair<QString,QString> > _linkMap;
-    Viewer* _viewer;
+    ViewerWidget* _viewer;
     QToolButton* _jumpToContext;
 };
 
